@@ -48,6 +48,10 @@ sup_Path =  pkg_resources.resource_filename(resource_package, sup_path)
 global Tr, bigQ, Chi, Pr, E_PrTr, bigR, Psi, Theta, Upsilon, Conversion, mineralDictionary
 
 mineralDictionary = json.load(open(mineralPath))
+try:
+    mineralDictionary2 = json.load(open(mineralPath2))
+except:
+    print('Extended Mineral Dictionary not in use')
 '''A dictionary that stores all the minerals and allows them to be queried for use in the DEW model.'''
 
 bigQ = 5.903E-07
@@ -132,7 +136,7 @@ def search(string):
         if str.lower(string) in str.lower(item):
             print(item)
     for key in mineralDictionary:
-        if str.lower(string) in str.lower(item):
+        if str.lower(string) in str.lower(key):
             print(key)
 
 
@@ -721,8 +725,8 @@ class DEW(object):
                     validBool = True
                 except ValueError:
                     print('You have entered a non-integer value, please start again')
-            tempArr = np.arange(start= templow, stop = temphigh + 1, step = tempstep)
-            parrHelp = np.arange(start= pmin, stop = pmax + .1, step = pstep)
+            tempArr = np.arange(start= templow, stop = temphigh + .00001, step = tempstep)
+            parrHelp = np.arange(start= pmin, stop = pmax + .00001, step = pstep)
             for i in range(len(parrHelp)):
                 pressArr.append([parrHelp[i]]* len(tempArr))
             pressArr = np.multiply(pressArr, 1000)
@@ -1131,7 +1135,7 @@ class DEW(object):
                 if self.psat == False:
                     myMinPath = mineralDictionary2
                 else: 
-                    myMinPath = mineralDictioanry
+                    myMinPath = mineralDictionary
                 for temp in self.tempUsed:
                     self.mineralInpGibbs.append(np.multiply(myMinPath[self.mineralInputs[i][0]]['delG'][myMinPath[self.mineralInputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
                     self.mineralInpV.append(np.multiply(myMinPath[self.mineralInputs[i][0]]['delV'][myMinPath[self.mineralInputs[i][0]]['Temperature'].index(temp)], int(self.mineralInputs[i][1]))) 
@@ -1218,24 +1222,11 @@ class DEW(object):
         self.delV = []
         
         if self.ptInput == "Custom":
-            ptSheet = pd.read_excel(DEW_Location, sheet_name = 'Input', header = None)
+            ptSheet =pd.read_csv(inpPath,encoding= 'unicode_escape', header = None)
             ptFinder = ptSheet.to_numpy()
-            pressArr = ptFinder[:,79][5:]
-            tempArr = ptFinder[:,80][5:]
-            storeidx = 0
-            storeidxP = 0
-            for i in range(len(tempArr)):
-                if np.isnan(tempArr[i]) == True:
-                    storeidx = int(i)
-                    break
-            for i in range(len(pressArr)):
-                if np.isnan(pressArr[i]) == True:
-                    storeidxP = int(i)
-                    break
-
-            tempArr = tempArr[:storeidx]
-            pressArr = pressArr[:storeidxP]
-
+            tempArr = [float(i[1]) for i in ptFinder[4:]]
+            pressArr = [float(i[0]) for i in ptFinder[4:]]
+            
         elif self.ptInput == "Regular":
             try:
                 templow = pt_arr[0][0]
